import 'dart:io';

import 'package:dio/dio.dart';
import 'VizzyApiClient.dart';

class VizzyService {
  VizzyApiClient client;

  VizzyService({String baseUrl, String userEmail, String userToken}) {
    final dio = Dio();
    dio.options.headers["X-User-Email"] = userEmail;
    dio.options.headers["X-User-Token"] = userToken;
    dio.options.baseUrl = baseUrl;
    // Uncomment this to enable debug logs
//    dio.interceptors.add(LogInterceptor(requestBody: true, responseBody: true));
    client = VizzyApiClient(dio);
  }

  Future<BuildInfo> createBuild(
      int projectId, String commitSha, String pullRequestNumber) {
    final buildRequest = CreateBuildRequest(
        projectId: projectId,
        commitSha: commitSha,
        pullRequestNumber: pullRequestNumber,
        devBuild: pullRequestNumber == null);
    return client.createBuild("application/json", buildRequest);
  }

  Future<BuildState> requestBuildInfo(BuildInfo buildInfo) {
    return client.getBuildState(buildInfo.id);
  }

  Future<BuildState> commitBuild(int buildId) {
    return client.commitBuild(buildId);
  }

  Future<ImageMd5Response> postImageMd5s(
      int buildId, ImageMd5Request imageMd5body) {
    return client.postImageMd5s("application/json", buildId, imageMd5body);
  }

  Future<UploadImageResponse> uploadImage(
      int buildId, File file, String fileName) async {
    return client.uploadImage(buildId, file, fileName);
  }
}
